@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '1.13.0';
+$Git::Hooks::CheckJira::VERSION = '1.13.1';
 use 5.010;
 use utf8;
 use strict;
@@ -371,16 +371,23 @@ sub notify_commit_msg {
 
     my $jira = _jira($git);
 
+    my $show = $git->command(show => '--stat', $commit->{commit});
+
     my %comment = (
-        body => "[$PKG] commit refers to this issue:\n\n"
-            . $git->command(show => '--stat', $commit->{commit}),
+        body => <<EOF,
+[$PKG] commit refers to this issue:
+
+{noformat}
+$show
+{noformat}
+EOF
     );
     $comment{visibility} = $visibility if $visibility;
 
     my $errors = 0;
 
     foreach my $key (@keys) {
-        eval { $jira->POST("/issue/$key/comment", \%comment); 1; }
+        eval { $jira->POST("/issue/$key/comment", undef, \%comment); 1; }
             or $git->error($PKG, "Cannot add a comment to JIRA issue $key:", $@)
             and ++$errors;
     }
@@ -413,16 +420,14 @@ sub notify_affected_refs {
     return 1 unless defined $comment;
 
     my $visibility;
-    if (length $comment) {
-        if ($comment =~ /^(role|group):(.+)/) {
-            $visibility = {
-                type  => $1,
-                value => $2,
-            };
-        } else {
-            $git->error($PKG, "Invalid argument to githooks.checkjira.comment: $comment");
-            return 0;
-        }
+    if ($comment =~ /^(role|group):(.+)/) {
+        $visibility = {
+            type  => $1,
+            value => $2,
+        };
+    } elsif ($comment ne 'all') {
+        $git->error($PKG, "Invalid argument to githooks.checkjira.comment: $comment");
+        return 0;
     }
 
     my $errors = 0;
@@ -459,7 +464,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 1.13.0
+version 1.13.1
 
 =head1 DESCRIPTION
 
@@ -727,7 +732,7 @@ If the subroutine returns undef it's considered to have succeeded.
 If it raises an exception (e.g., by invoking B<die>) it's considered
 to have failed and a proper message is produced to the user.
 
-=head2 githooks.checkjira.comment [VISIBILITY]
+=head2 githooks.checkjira.comment VISIBILITY
 
 If this option is set and the C<post-receive> hook is enabled, for every
 pushed commit, every cited JIRA issue receives a comment showing the result
@@ -739,19 +744,22 @@ permission to add comments to the issues or an error will be
 logged. However, since this happens after the push, the result of the
 operation isn't affected.
 
-You can restrict the visibility of comments with the optional argument,
-which must be in the form TYPE:VALUE, where TYPE may be one of:
+You must specify the VISIBILITY of the comments in one of these ways.
 
 =over
 
-=item * B<role>
+=item * B<role:NAME>
 
-In this case, VALUE must be the name of a JIRA role, such as
+In this case, NAME must be the name of a JIRA role, such as
 C<Administrators>, C<Developers>, or C<Users>.
 
-=item * B<group>
+=item * B<group:NAME>
 
-In this case, VALUE must be the name of a JIRA group.
+In this case, NAME must be the name of a JIRA group.
+
+=item * B<all>
+
+In this case, the visibility isn't restricted at all.
 
 =back
 
